import React from 'react';
import PropTypes from 'prop-types';
import Container from 'reactstrap/lib/Container';
import classNames from 'classnames';
import { IfElse } from '../helpers/if-else';
import './header.scss';

export function Header({
  children, isWhite, isSolid, isStretched,
}) {
  const containerClasses = 'h-100 d-flex justify-content-between';
  return (
    <Container
      tag="header"
      fluid
      className={classNames('header p-0', {
        'bg-white header-white': isWhite,
        'bg-darkblue-db40': isSolid,
        'header-with-gradient': !isWhite && !isSolid,
      })}
    >
      {/* TODO: Consider responsive then */}
      <IfElse condition={isStretched}>
        <div className={`px-3 ${containerClasses}`}>{children}</div>
        <Container className={containerClasses}>{children}</Container>
      </IfElse>
    </Container>
  );
}

Header.propTypes = {
  children: PropTypes.node.isRequired,
  isWhite: PropTypes.bool,
  isSolid: PropTypes.bool,
  isStretched: PropTypes.bool,
};

Header.defaultProps = {
  isWhite: false,
  isSolid: false,
  isStretched: false,
};
