import {
  PRODUCTION,
  DEVELOPMENT,
  STAGING,
  RELEASE,
  DEFAULT_LOCALE,
  LOCALES_DOMAIN_MAPPING,
} from '../constants';

export const SCORUM_MULTI_DOMAIN = `scorum.${process.env.DOMAIN || 'com'}`;

export const WALLET_URLS = {
  [DEVELOPMENT]: 'wallet-dev.scorum.com',
  [STAGING]: 'wallet-staging.scorum.com',
  [RELEASE]: 'wallet-staging.scorum.com',
  [PRODUCTION]: 'wallet.scorum.com',
};

export const BET_URLS = {
  [DEVELOPMENT]: 'bet-dev.scorum.com',
  [STAGING]: 'bet-staging.scorum.com',
  [RELEASE]: 'bet-release.scorum.com',
  [PRODUCTION]: 'bet.scorum.com',
};

export const BLOG_URLS = {
  [DEVELOPMENT]: 'blog-dev.scorum',
  [STAGING]: 'blog-staging.scorum',
  [RELEASE]: 'blog-release.scorum',
  [PRODUCTION]: 'scorum',
};

export const getWalletUrl = () =>
  `//${WALLET_URLS[process.env.PROJECT_ENV] || WALLET_URLS[DEVELOPMENT]}`;

export const getBlogUrl = (locale = DEFAULT_LOCALE) => {
  if (!BLOG_URLS[process.env.PROJECT_ENV]) {
    return `//${BLOG_URLS[DEVELOPMENT]}.${LOCALES_DOMAIN_MAPPING[locale]}`;
  }

  return `//${BLOG_URLS[process.env.PROJECT_ENV]}.${LOCALES_DOMAIN_MAPPING[locale]}`;
};

export const getBettingUrl = () =>
  `//${BET_URLS[process.env.PROJECT_ENV] || BET_URLS[DEVELOPMENT]}`;

export const getProductUrl = (service, locale) => {
  const urlLocale = locale ? `/${locale}/` : '';

  switch (service) {
    case 'blog':
      return `${getBlogUrl(locale)}${urlLocale}`;
    case 'wallet':
      return `${getWalletUrl()}${urlLocale}`;
    case 'betting':
      return `${getBettingUrl()}${urlLocale}`;
    default:
      return `//${service}.${SCORUM_MULTI_DOMAIN}`;
  }
};
