import GA from './ga';
import * as generalHelpers from './general';

jest.spyOn(generalHelpers, 'canUseDOM');

describe('', () => {
  window.gtag = jest.fn();
  window.fbq = jest.fn();
  window.GoogleAnalyticsObject = 'testGAObj';
  window.testGAObj = jest.fn();

  describe('when canUseDOM', () => {
    beforeAll(() => {
      generalHelpers.canUseDOM.mockReturnValue(true);
    });

    describe('setUser', () => {
      test('should set user', () => {
        GA.setUser('test');
      });
    });

    describe('trackPage', () => {
      test('should track page', () => {
        GA.trackPage('test');
      });
    });

    describe('#event', () => {
      test('should event', () => {
        GA.event({});
      });

      test('should event', () => {
        GA.event({
          category: 'category',
          action: 'action',
        });
      });

      test('should event with fbCategory', () => {
        GA.event({
          category: 'category',
          action: 'action',
          fbCategory: 'fbCategory',
        });
      });
    });

    describe('when PROJECT_ENV is production', () => {
      beforeAll(() => {
        process.env.PROJECT_ENV = 'production';
      });

      afterAll(() => {
        process.env.PROJECT_ENV = 'development';
      });

      test('should not log', () => {
        console.log = jest.fn();

        GA.event({
          category: 'category',
          action: 'action',
        });
        GA.setUser('test');
        GA.trackPage('test');

        expect(console.log).not.toHaveBeenCalled();
      });
    });
  });

  describe('when NOT canUseDOM', () => {
    beforeAll(() => {
      generalHelpers.canUseDOM.mockReturnValue(false);
    });

    describe('setUser', () => {
      test('should set user', () => {
        GA.setUser('test');
      });
    });

    describe('trackPage', () => {
      test('should track page', () => {
        GA.trackPage('test');
      });
    });

    describe('#event', () => {
      test('should event', () => {
        GA.event({
          category: 'category',
          action: 'action',
        });
      });
    });
  });
});
